# myke

> The dynamic Python CLI for convenient task execution.

| Links         |                                       |
|---------------|---------------------------------------|
| Code Repo     | https://www.github.com/fresh2dev/myke |
| Documentation | https://www.f2dv.com/r/myke           |
| Changelog     | https://www.f2dv.com/r/myke/changelog |
| License       | https://www.f2dv.com/r/myke/license   |
| Funding       | https://www.f2dv.com/fund             |

[![GitHub Repo stars](https://img.shields.io/github/stars/fresh2dev/myke?color=blue&style=for-the-badge)](https://star-history.com/#fresh2dev/myke&Date)
[![GitHub release (latest SemVer)](https://img.shields.io/github/v/release/fresh2dev/myke?color=blue&style=for-the-badge)](https://www.f2dv.com/r/myke/changelog)
[![GitHub Release Date](https://img.shields.io/github/release-date/fresh2dev/myke?color=blue&style=for-the-badge)](https://www.f2dv.com/r/myke/changelog)
[![License](https://img.shields.io/github/license/fresh2dev/myke?color=blue&style=for-the-badge)](https://www.f2dv.com/r/myke/license)
<!-- [![GitHub issues](https://img.shields.io/github/issues-raw/fresh2dev/myke?color=blue&style=for-the-badge)](https://www.github.com/fresh2dev/myke/issues) -->
<!-- [![GitHub pull requests](https://img.shields.io/github/issues-pr-raw/fresh2dev/myke?color=blue&style=for-the-badge)](https://www.github.com/fresh2dev/myke/pulls) -->
<!-- [![PyPI - Downloads](https://img.shields.io/pypi/dm/myke?color=blue&style=for-the-badge)](https://pypi.org/project/myke) -->
<!-- [![Docker Pulls](https://img.shields.io/docker/pulls/fresh2dev/myke?color=blue&style=for-the-badge)](https://hub.docker.com/r/fresh2dev/myke) -->
<!-- [![Funding](https://img.shields.io/badge/funding-%24%24%24-blue?style=for-the-badge)](https://www.f2dv.com/fund) -->

---

## Overview

...

## Install

...

## Use

...

## Support

If this project delivers value to you, please [provide feedback](https://www.github.com/fresh2dev/myke/issues), code contributions, and/or [funding](https://www.f2dv.com/fund).

*Brought to you by...*

<a href="https://www.f2dv.com"><img src="https://img.fresh2.dev/fresh2dev.svg" style="filter: invert(50%);"></img></a>
